@@ -5,13 +5,12 @@
 //! - Indicators are the combinations of [`Operator`]s. We can chain them by [`OperatorExt::then`]
 //! and apply them to the same input "simultaneously" by [`OperatorExt::facet`].
 //!
-//! - To handle [Time series] better, we introduced [`TickedOperatorExt`] operators,
-//! of which the input and output are both [`Tickable`] (the items in time series)
-//! and sharing the same [`Tick`]. We provide many ticked version utils. For example,
-//! we can apply different [`TickedOperatorExt`]s (using [`TickedOperatorExt::facet_t`] or [`ticked::FacetMap`])
-//! to the same [`Tickable`] stream to get a "synced" result stream of the combined outputs of
-//! those operators sharing the same [`Tick`] of theirs input.
-//! Each item of a "synced" stream will have the form of `TickValue<(O1, O2)>`.
+//! - To handle [Time series] better, we introduced utils for ticked operators, which are defined in [`TickedOperatorExt`],
+//! of which the input and output are both [`Tickable`] and sharing the same [`Tick`].
+//! We provide many ticked version utils. For example, we can apply different [`TickedOperatorExt`]s
+//! (using [`TickedOperatorExt::facet_t`] or [`ticked::FacetMap`]) to the same [`Tickable`] stream to
+//! get a "synced" result stream of the combined outputs of those operators sharing the same [`Tick`]
+//! of theirs input. Each item of a "synced" stream will have the form of `TickValue<(O1, O2)>`.
 //!
 //! - [`TumblingOperator`]s are defined by some operations on events of non-overlapping time windows ([`TumblingWindow`]).
 //! [Moving average] is one of the famous examples, which is defined by the average of the numbers
@@ -29,10 +28,11 @@
 //! ```
 //! use indicator::*;
 //! use rust_decimal::Decimal;
+//! use rust_decimal_macros::dec;
 //! use time::macros::offset;
 //! use arrayvec::ArrayVec;
 //!
-//! /// Return an indicator that calculate `hl2` and `ohlc4` simultaneously.
+//! /// Return an indicator that calculates `hl2` and `ohlc4` simultaneously.
 //! fn hl2_ohlc4(period: Period) -> impl Operator<TickValue<Decimal>, Output = (Decimal, Decimal)> {
 //!     tumbling(
 //!         period,
@@ -81,7 +81,10 @@ pub use iter::IndicatorIteratorExt;
 pub use operator::{facet, map, Operator, OperatorExt};
 pub use ticked::{
     facet_t, map_t,
-    tumbling::{tumbling, QueueCapAtLeast, TumblingOperation, TumblingOperator, TumblingQueue},
+    tumbling::{
+        cached, tumbling, Cached, CachedOperation, QueueCapAtLeast, TumblingOperation,
+        TumblingOperator, TumblingQueue,
+    },
     TickedOperatorExt,
 };
 pub use window::{Period, Tick, TickValue, Tickable, TumblingWindow};
@@ -89,5 +92,8 @@ pub use window::{Period, Tick, TickValue, Tickable, TumblingWindow};
 #[cfg(feature = "std")]
 pub use ticked::facet_map_t;
 
+#[cfg(feature = "std")]
+pub use ticked::{shared, SharedMap};
+
 #[cfg(feature = "stream")]
 pub use stream::IndicatorStreamExt;
